==> Spire.Pdf-9.12.0-py3-none-win_amd64.whl: spire/pdf/PdfSignatureMaker.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfSignatureMaker(SpireObject):
    """
    Pdf signature maker.
    """

    @property
    def Signature(self) -> 'PdfSignature':
        """
        The signature.
        """
        GetDllLibPdf().PdfSignatureMaker_get_Signature.argtypes = [c_void_p]
        GetDllLibPdf().PdfSignatureMaker_get_Signature.restype = c_void_p
        intPtr = GetDllLibPdf().PdfSignatureMaker_get_Signature(self.Ptr)
        ret = None if intPtr == None else PdfSignature(intPtr)
        return ret

    def SetName(self, name: str):
        """
        Set the name of the person or authority signing the document.
        This value should be used only when it is not possible to extract the name from the signature,
        for example, from the certificate of the signer.
        """
        GetDllLibPdf().PdfSignatureMaker_SetName.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfSignatureMaker_SetName(self.Ptr, name)

    def SetDistinguishedName(self, distinguishedName: str):
        """
        Set the digital signature distinguished name.
        Notes: Assigning a string value to it directly is not recommended unless you know what the Distinguished Name exactly is.
        One suggested way of value assignment is using pdfSignature.Certificate.IssuerName.Name,
        where pdfSignature is an instance of the PDFSignature class.
        """
        GetDllLibPdf().PdfSignatureMaker_SetDistinguishedName.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfSignatureMaker_SetDistinguishedName(self.Ptr, distinguishedName)

    def SetDate(self, date: str):
        """
        Set the time of signing.
        It is recommended to use "D:{0:yyyyMMddHHmmss}" to format the datetime,
        for example: String.Format("D:{0:yyyyMMddHHmmss}", DateTime.Now).
        Depending on the signature handler, this may be a normal unverified computer time
        or a time generated in a verifiable way from a secure time server.
        """
        GetDllLibPdf().PdfSignatureMaker_SetDate.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfSignatureMaker_SetDate(self.Ptr, date)

    def SetLocation(self, location: str):
        """
        Set the CPU host name or physical location of the signing.
        """
        GetDllLibPdf().PdfSignatureMaker_SetLocation.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfSignatureMaker_SetLocation(self.Ptr, location)

    def SetReason(self, reason: str):
        """
        Set the reason for the signing, such as "I agree...".
        """
        GetDllLibPdf().PdfSignatureMaker_SetReason.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfSignatureMaker_SetReason(self.Ptr, reason)

    def SetContactInfo(self, contactInfo: str):
        """
        Set the information provided by the signer to enable a recipient to contact the signer to verify the signature,
        for example, a phone number.
        """
        GetDllLibPdf().PdfSignatureMaker_SetContactInfo.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfSignatureMaker_SetContactInfo(self.Ptr, contactInfo)

    def SetNameLabel(self, nameLabel: str):
        """
        Set the content to the left of the property name.
        """
        GetDllLibPdf().PdfSignatureMaker_SetNameLabel.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfSignatureMaker_SetNameLabel(self.Ptr, nameLabel)

    def SetDistinguishedNameLabel(self, distinguishedNameLabel: str):
        """
        Set the content to the left of the property distinguishedName.
        """
        GetDllLibPdf().PdfSignatureMaker_SetDistinguishedNameLabel.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfSignatureMaker_SetDistinguishedNameLabel(self.Ptr, distinguishedNameLabel)

    def SetReasonLabel(self, reasonLabel: str):
        """
        Set the content to the left of the property reason.
        """
        GetDllLibPdf().PdfSignatureMaker_SetReasonLabel.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfSignatureMaker_SetReasonLabel(self.Ptr, reasonLabel)

    def SetLocationLabel(self, locationLabel: str):
        """
        Set the content to the left of the property location.
        """
        GetDllLibPdf().PdfSignatureMaker_SetLocationLabel.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfSignatureMaker_SetLocationLabel(self.Ptr, locationLabel)

    def SetContactInfoLabel(self, contactInfoLabel: str):
        """
        Set the content to the left of the property contactInfo.
        """
        GetDllLibPdf().PdfSignatureMaker_SetContactInfoLabel.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfSignatureMaker_SetContactInfoLabel(self.Ptr, contactInfoLabel)

    def SetDateLabel(self, dateLabel: str):
        """
        Set the content to the left of the property date.
        """
        GetDllLibPdf().PdfSignatureMaker_SetDateLabel.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfSignatureMaker_SetDateLabel(self.Ptr, dateLabel)

    def SetAcro6Layers(self, acro6Layers: bool):
        """
        Set whether to move away signature validity visualizations in the document.
        Only for compatibility with old versions.
        Default is true.
        """
        GetDllLibPdf().PdfSignatureMaker_SetAcro6Layers.argtypes = [c_void_p, c_bool]
        GetDllLibPdf().PdfSignatureMaker_SetAcro6Layers(self.Ptr, acro6Layers)

    @dispatch
    def MakeSignature(self, sigFieldName: str):
        """
        Make a signature.
        """
        GetDllLibPdf().PdfSignatureMaker_MakeSignature.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfSignatureMaker_MakeSignature(self.Ptr, sigFieldName)

    @dispatch
    def MakeSignature(self, sigFieldName: str, signatureAppearance: IPdfSignatureAppearance):
        """
        Make a signature with a custom signature appearance.
        """
        intPtrsignatureAppearance: c_void_p = signatureAppearance.Ptr

        GetDllLibPdf().PdfSignatureMaker_MakeSignatureSS.argtypes = [c_void_p, c_wchar_p, c_void_p]
        GetDllLibPdf().PdfSignatureMaker_MakeSignatureSS(self.Ptr, sigFieldName, intPtrsignatureAppearance)

    @dispatch
    def MakeSignature(self, sigFieldName: str, page: PdfPageBase, x: float, y: float, width: float, height: float):
        """
        Make a signature on a specific page at a specific location.
        """
        intPtrpage: c_void_p = page.Ptr

        GetDllLibPdf().PdfSignatureMaker_MakeSignatureSPXYWH.argtypes = [c_void_p, c_wchar_p, c_void_p, c_float, c_float, c_float, c_float]
        GetDllLibPdf().PdfSignatureMaker_MakeSignatureSPXYWH(self.Ptr, sigFieldName, intPtrpage, x, y, width, height)

    @dispatch
    def MakeSignature(self, sigFieldName: str, page: PdfPageBase, x: float, y: float, width: float, height: float, signatureAppearance: IPdfSignatureAppearance):
        """
        Make a signature on a specific page at a specific location with a custom signature appearance.
        """
        intPtrpage: c_void_p = page.Ptr
        intPtrsignatureAppearance: c_void_p = signatureAppearance.Ptr

        GetDllLibPdf().PdfSignatureMaker_MakeSignatureSPXYWHS.argtypes = [c_void_p, c_wchar_p, c_void_p, c_float, c_float, c_float, c_float, c_void_p]
        GetDllLibPdf().PdfSignatureMaker_MakeSignatureSPXYWHS(self.Ptr, sigFieldName, intPtrpage, x, y, width, height, intPtrsignatureAppearance)

==> Spire.Pdf-10.12.1-py3-none-win_amd64.whl: spire/pdf/PdfSignatureMaker.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfSignatureMaker(SpireObject):
    """
    Pdf signature maker.
    """

    @property
    def Signature(self) -> 'PdfSignature':
        """
        The signature.
        """
        GetDllLibPdf().PdfSignatureMaker_get_Signature.argtypes = [c_void_p]
        GetDllLibPdf().PdfSignatureMaker_get_Signature.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfSignatureMaker_get_Signature,self.Ptr)
        ret = None if intPtr == None else PdfSignature(intPtr)
        return ret

    def SetName(self, name: str):
        """
        Set the name of the person or authority signing the document.
        This value should be used only when it is not possible to extract the name from the signature,
        for example, from the certificate of the signer.
        """
        GetDllLibPdf().PdfSignatureMaker_SetName.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfSignatureMaker_SetName,self.Ptr, name)

    def SetDistinguishedName(self, distinguishedName: str):
        """
        Set the digital signature distinguished name.
        Notes: Assigning a string value to it directly is not recommended unless you know what the Distinguished Name exactly is.
        One suggested way of value assignment is using pdfSignature.Certificate.IssuerName.Name,
        where pdfSignature is an instance of the PDFSignature class.
        """
        GetDllLibPdf().PdfSignatureMaker_SetDistinguishedName.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfSignatureMaker_SetDistinguishedName,self.Ptr, distinguishedName)

    def SetDate(self, date: str):
        """
        Set the time of signing.
        It is recommended to use "D:{0:yyyyMMddHHmmss}" to format the datetime,
        for example: String.Format("D:{0:yyyyMMddHHmmss}", DateTime.Now).
        Depending on the signature handler, this may be a normal unverified computer time
        or a time generated in a verifiable way from a secure time server.
        """
        GetDllLibPdf().PdfSignatureMaker_SetDate.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfSignatureMaker_SetDate,self.Ptr, date)

    def SetLocation(self, location: str):
        """
        Set the CPU host name or physical location of the signing.
        """
        GetDllLibPdf().PdfSignatureMaker_SetLocation.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfSignatureMaker_SetLocation,self.Ptr, location)

    def SetReason(self, reason: str):
        """
        Set the reason for the signing, such as "I agree...".
        """
        GetDllLibPdf().PdfSignatureMaker_SetReason.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfSignatureMaker_SetReason,self.Ptr, reason)

    def SetContactInfo(self, contactInfo: str):
        """
        Set the information provided by the signer to enable a recipient to contact the signer to verify the signature,
        for example, a phone number.
        """
        GetDllLibPdf().PdfSignatureMaker_SetContactInfo.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfSignatureMaker_SetContactInfo,self.Ptr, contactInfo)

    def SetNameLabel(self, nameLabel: str):
        """
        Set the content to the left of the property name.
        """
        GetDllLibPdf().PdfSignatureMaker_SetNameLabel.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfSignatureMaker_SetNameLabel,self.Ptr, nameLabel)

    def SetDistinguishedNameLabel(self, distinguishedNameLabel: str):
        """
        Set the content to the left of the property distinguishedName.
        """
        GetDllLibPdf().PdfSignatureMaker_SetDistinguishedNameLabel.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfSignatureMaker_SetDistinguishedNameLabel,self.Ptr, distinguishedNameLabel)

    def SetReasonLabel(self, reasonLabel: str):
        """
        Set the content to the left of the property reason.
        """
        GetDllLibPdf().PdfSignatureMaker_SetReasonLabel.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfSignatureMaker_SetReasonLabel,self.Ptr, reasonLabel)

    def SetLocationLabel(self, locationLabel: str):
        """
        Set the content to the left of the property location.
        """
        GetDllLibPdf().PdfSignatureMaker_SetLocationLabel.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfSignatureMaker_SetLocationLabel,self.Ptr, locationLabel)

    def SetContactInfoLabel(self, contactInfoLabel: str):
        """
        Set the content to the left of the property contactInfo.
        """
        GetDllLibPdf().PdfSignatureMaker_SetContactInfoLabel.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfSignatureMaker_SetContactInfoLabel,self.Ptr, contactInfoLabel)

    def SetDateLabel(self, dateLabel: str):
        """
        Set the content to the left of the property date.
        """
        GetDllLibPdf().PdfSignatureMaker_SetDateLabel.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfSignatureMaker_SetDateLabel,self.Ptr, dateLabel)

    def SetAcro6Layers(self, acro6Layers: bool):
        """
        Set whether to move away signature validity visualizations in the document.
        Only for compatibility with old versions.
        Default is true.
        """
        GetDllLibPdf().PdfSignatureMaker_SetAcro6Layers.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfSignatureMaker_SetAcro6Layers,self.Ptr, acro6Layers)

    @dispatch
    def MakeSignature(self, sigFieldName: str):
        """
        Make a signature.
        """
        GetDllLibPdf().PdfSignatureMaker_MakeSignature.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfSignatureMaker_MakeSignature,self.Ptr, sigFieldName)

    @dispatch
    def MakeSignature(self, sigFieldName: str, signatureAppearance: IPdfSignatureAppearance):
        """
        Make a signature with a custom signature appearance.
        """
        intPtrsignatureAppearance: c_void_p = signatureAppearance.Ptr

        GetDllLibPdf().PdfSignatureMaker_MakeSignatureSS.argtypes = [c_void_p, c_wchar_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfSignatureMaker_MakeSignatureSS,self.Ptr, sigFieldName, intPtrsignatureAppearance)

    @dispatch
    def MakeSignature(self, sigFieldName: str, page: PdfPageBase, x: float, y: float, width: float, height: float):
        """
        Make a signature on a specific page at a specific location.
        """
        intPtrpage: c_void_p = page.Ptr

        GetDllLibPdf().PdfSignatureMaker_MakeSignatureSPXYWH.argtypes = [c_void_p, c_wchar_p, c_void_p, c_float, c_float, c_float, c_float]
        CallCFunction(GetDllLibPdf().PdfSignatureMaker_MakeSignatureSPXYWH,self.Ptr, sigFieldName, intPtrpage, x, y, width, height)

    @dispatch
    def MakeSignature(self, sigFieldName: str, page: PdfPageBase, x: float, y: float, width: float, height: float, signatureAppearance: IPdfSignatureAppearance):
        """
        Make a signature on a specific page at a specific location with a custom signature appearance.
        """
        intPtrpage: c_void_p = page.Ptr
        intPtrsignatureAppearance: c_void_p = signatureAppearance.Ptr

        GetDllLibPdf().PdfSignatureMaker_MakeSignatureSPXYWHS.argtypes = [c_void_p, c_wchar_p, c_void_p, c_float, c_float, c_float, c_float, c_void_p]
        CallCFunction(GetDllLibPdf().PdfSignatureMaker_MakeSignatureSPXYWHS,self.Ptr, sigFieldName, intPtrpage, x, y, width, height, intPtrsignatureAppearance)
